# Installation

## Installation from PyPI

Coming soon!

## Installation from Source

```bash
$ git clone https://github.com/saifkhichi96/pocket-pose.git
$ cd pocket-pose
$ pip install .
```

For development, you can install the package in editable mode:

```bash
$ pip install -e .
```
